<?php

namespace SM\Controller;

use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use SM\Service\CdaService;
use SM\Service\SmNextDocumentoCdaService;
use SM\Traits\TResponse;
use Zeedhi\Framework\DataSource\DataSet;

class CdaController
{
    use TResponse;
    
    protected $CdaService;
    protected $DocumentoCdaService;
    
    public function __construct(CdaService $CdaService, SmNextDocumentoCdaService $DocumentoCdaService)
    {
        $this->CdaService = $CdaService;
        $this->DocumentoCdaService = $DocumentoCdaService;
    }
    
    public function getCda(Request $request)
    {
        try {
            $data = $this->CdaService->getCda($request->getParameters());
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getFuncionarios(Request $request)
    {
        try {
            $data = $this->CdaService->getFuncionarios($request->getParameters());
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getPermissaoOperadorCda(Request $request)
    {
        try {
            $data = $this->CdaService->getPermissaoOperadorCda($request->getParameters());
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getOperadorLogado()
    {
        try {
            $data = $this->CdaService->getOperadorLogado();
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getPeriodoApuraPonto(Request $request)
    {
        try {
            $data = $this->CdaService->getPeriodoApuraPonto($request->getParameters());
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getClienteCda(Request $request)
    {
        try {
            $data = $this->CdaService->getClienteCda($request->getParameters());
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getClienteRelacionamento()
    {
        try {
            $data = $this->CdaService->getClienteRelacionamento();
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getPropostaCda(Request $request)
    {
        try {
            $data = $this->CdaService->getPropostaCda($request->getParameters());
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getProjetoOperadorCliente(Request $request)
    {
        try {
            $data = $this->CdaService->getProjetoOperadorCliente($request->getParameters());
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getTipoAtividadeCda(Request $request)
    {
        try {
            $data = $this->CdaService->getTipoAtividadeCda($request->getParameters());
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getProspectCda(Request $request)
    {
        try {
            $data = $this->CdaService->getProspectCda($request->getParameters());
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getInterlocutorProspectCda(Request $request)
    {
        try {
            $data = $this->CdaService->getInterlocutorProspectCda($request->getParameters());
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }
    
    public function getInterlocutorClienteCda(Request $request)
    {
        try {
            $data = $this->CdaService->getInterlocutorClienteCda($request->getParameters());
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getLicencaUsoCda(Request $request)
    {
        try {
            $data = $this->CdaService->getLicencaUsoCda($request->getParameters());
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getContatosParceiroCda(Request $request)
    {
        try {
            $data = $this->CdaService->getContatosParceiroCda($request->getParameters());
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getMotivoEvoContCda(Request $request)
    {
        try {
            $data = $this->CdaService->getMotivoEvoContCda($request->getParameters());
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }
    
    public function getMotivoContatoCda(Request $request)
    {
        try {
            $data = $this->CdaService->getMotivoContatoCda($request->getParameters());
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getSistemaCda(Request $request)
    {
        try {
            $data = $this->CdaService->getSistemaCda($request->getParameters());
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function deleteParticipantes(Request $request)
    {
        try {
            $data = $this->CdaService->deleteParticipantes($request->getParameters());
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getParticipantesCda(Request $request)
    {
        try {
            $data = $this->CdaService->getParticipantesCda($request->getParameters());
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function inserirAtividadeCda(Request $request)
    {
        try {
            $data = $this->CdaService->inserirAtividadeCda($request->getParameters());
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getHorasNaoFaturadas(Request $request)
    {
        try {
            $data = $this->CdaService->getHorasNaoFaturadas($request->getParameters());
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function existenciaCda(Request $request)
    {
        try {
            $data = $this->CdaService->existenciaCda($request->getParameters());
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getDescricaoCda(Request $request)
    {
        try {
            $data = $this->CdaService->getDescricaoCda($request->getParameters());
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function confirmaOuCorrigeCda(Request $request)
    {
        try {
            $data = $this->CdaService->confirmaOuCorrigeCda($request->getParameters());
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function deletarCda(Request $request)
    {
        try {
            $data = $this->CdaService->deletarCda($request->getParameters());
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function gerarDocumentoCda(Request $request, Response $response)
    {
        try {
            $data = $this->DocumentoCdaService->mergeDocCda($request->getParameters());
            $this->sendResponse(['link' => $data], 200);
        } catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }

    public function inserirRepresentante(Request $request, Response $response)
    {
        try {
            $data = $this->CdaService->inserirRepresentante($request->getParameters());
            $this->sendResponse($data, 200);
        } catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
}
