/* Sistemas Integrados TECNISA
   Planejamento Alimentao Industrial

Nome: QUANTIDADE_DO_PRODUTO_PLA.SQL

Descrio:
Retorna a quantidade do Produto em uma determinada data.

P_CDFILIAL     - Cdigo da Filial.
P_CDPRODUTO    - Cdigo do Produto.
P_DTREFERENCIA - Data da retirada.

@C:\Web_605\Sql\End_Conv\Oracle\0313_CUSFUNO_QTDE_PROD_LCEST.SQL

Criao:
12/12/2017 - Cristiane Faria

P_ALMOXARIFE = 'N' Indica que sera verificado os parametros de almoxarifado, localizacao e lote padrao.

Manutenes:
__/__/____ - _______ ___________
__/__/____ - _______ ___________
__/__/____ - _______ ___________
__/__/____ - _______ ___________
*/

IF EXISTS (SELECT *
           FROM SYSOBJECTS O, SYSUSERS U
           WHERE O.NAME = 'QTDE_PRODUTO_LCEST' AND
                 TYPE = 'FN' AND
                 U.UID = O.UID  AND
                 U.NAME = USER)
DROP FUNCTION QTDE_PRODUTO_LCEST
GO

CREATE FUNCTION QTDE_PRODUTO_LCEST
  (@P_CDFILIAL     VARCHAR(04),
   @P_CDPRODUTO    VARCHAR(10),
   @P_DTREFERENCIA DATETIME,
   @P_ALMOXARIFE   VARCHAR(06) = ' ',
   @P_LOCALESTOQ   VARCHAR(06) = ' ',
   @P_NRLOTEESTQ   VARCHAR(20) = ' ',
   @P_NRSUBLOTE    VARCHAR(04) = ' ')

RETURNS DOUBLE PRECISION

AS

BEGIN

   DECLARE @V_CDALMOXARIFE  VARCHAR(06);
   DECLARE @V_CDLOCALESTOQ  VARCHAR(06);
   DECLARE @V_NRLOTEESTQ    VARCHAR(20);
   DECLARE @V_NRSUBLOTE     VARCHAR(04);
   DECLARE @V_QTESTOQDIA    DOUBLE PRECISION;

   DECLARE @FILIAL_IDCTRLESTQ    VARCHAR(01);
   DECLARE @FILIAL_IDUTILALMOX   VARCHAR(01);
   DECLARE @FILIAL_IDUTILLCESTQ  VARCHAR(01);
   DECLARE @FILIAL_IDUTILLOTE    VARCHAR(01);
   DECLARE @FILIAL_CDALMOXARIFE  VARCHAR(06);
   DECLARE @FILIAL_CDLOCALESTOQ  VARCHAR(06);

   DECLARE @PROD_IDUTCTRLLOTE    VARCHAR(01);
   DECLARE @PROD_CDALMOXARIFE    VARCHAR(06);
   DECLARE @PROD_CDLOCALESTOQ    VARCHAR(06);
   DECLARE @PROD_IDUTILLOTE      VARCHAR(01);

   DECLARE @LOTE_CDFILIAL        VARCHAR(04);

   SET @V_CDALMOXARIFE  = @P_ALMOXARIFE;
   SET @V_CDLOCALESTOQ  = @P_LOCALESTOQ;
   SET @V_NRLOTEESTQ    = @P_NRLOTEESTQ;
   SET @V_NRSUBLOTE     = @P_NRSUBLOTE;

   /*CASO O PARAMETRO DE ALMOXARIFADO NO TENHA SIDO PASSADO, AI VERIFICA O ALMOXARIFADO, LOCALIZACAO E LOTE PADRAO. NO CASO O N INDICA QUE NAO FOI DEFINIDO*/
   IF @P_ALMOXARIFE = 'N' BEGIN

      /*PARAMETRO POR FILIAL*/
      SELECT @FILIAL_IDCTRLESTQ   = ISNULL(IDCTRLESTQ,'N'),
             @FILIAL_IDUTILALMOX  = ISNULL(IDUTILALMOX,'N'),
             @FILIAL_IDUTILLCESTQ = ISNULL(IDUTILLCESTQ,'N'),
             @FILIAL_IDUTILLOTE   = ISNULL(IDUTILLOTE,'N'),
             @FILIAL_CDALMOXARIFE = ISNULL(CDALMOXARIFE,'N'),
             @FILIAL_CDLOCALESTOQ = ISNULL(CDLOCALESTOQ,'N')
        FROM PARAMFILIAL
       WHERE CDFILIAL = @P_CDFILIAL;

      /*PARAMETRO POR PRODUTO*/
      SELECT @PROD_IDUTCTRLLOTE = ISNULL(PF.IDUTCTRLLOTE,'N'),
             @PROD_CDALMOXARIFE = PF.CDALMOXARIFE,
             @PROD_CDLOCALESTOQ = PF.CDLOCALESTOQ,
             @PROD_IDUTILLOTE   = ISNULL(F.IDUTILLOTE,'N')
        FROM PRODFILI PF, PRODUTO P, PARAMFILIAL F
       WHERE (PF.CDFILIAL  = @P_CDFILIAL)  AND
             (P.CDPRODUTO  = @P_CDPRODUTO) AND
             (PF.CDPRODUTO = P.CDPRODESTO) AND
             (PF.CDFILIAL  = F.CDFILIAL);

      /*VERIFICA SE A FILIAL CONTROLA ESTOQUE*/
      IF ISNULL(@FILIAL_IDCTRLESTQ,'N') <> 'N' BEGIN
          /*VERIFICA SE A FILIAL UTILIZA ALMOXARIFADO (ALMOXARIFADO_PADRAO)*/
          IF ISNULL(@FILIAL_IDUTILALMOX,'N') = 'S' BEGIN
             IF ISNULL(@PROD_CDALMOXARIFE,'N') = 'N' BEGIN
                SET @V_CDALMOXARIFE = @FILIAL_CDALMOXARIFE;
             END
             ELSE BEGIN
                SET @V_CDALMOXARIFE = @PROD_CDALMOXARIFE;
             END;
          END
          ELSE BEGIN
             SET @V_CDALMOXARIFE = ' ';
          END;

          /*VERIFICA SE A FILIAL UTILIZA LOCALIZACAO  (LOCALESTOQUE_PADRAO)*/
          IF ISNULL(@FILIAL_IDUTILLCESTQ,'N') = 'S' BEGIN
             IF ISNULL(@PROD_CDLOCALESTOQ,'N') = 'N' BEGIN
                SET @V_CDLOCALESTOQ = @FILIAL_CDLOCALESTOQ;
             END
             ELSE BEGIN
                SET @V_CDLOCALESTOQ = @PROD_CDLOCALESTOQ;
             END;
          END
          ELSE BEGIN
             SET @V_CDLOCALESTOQ = ' ';
          END;
      END
      ELSE BEGIN
         SET @V_CDALMOXARIFE = ' ';
         SET @V_CDLOCALESTOQ = ' ';
      END;

      /*(CONSULTA_LOTE)*/
      /*SE A FILIAL NAO UTILIZAR LOTE*/
/*      IF ISNULL(@FILIAL_IDUTILLOTE,'N') <> 'S' BEGIN
         SET @V_NRLOTEESTQ    = ' ';
         SET @V_NRSUBLOTE     = ' ';
      END
      ELSE BEGIN
         IF @PROD_IDUTCTRLLOTE <> 'S' BEGIN
            SET @V_NRLOTEESTQ  = ' ';
            SET @V_NRSUBLOTE   = ' ';
         END
         ELSE BEGIN
            SELECT @V_NRLOTEESTQ = NRLOTEESTQ,
                   @V_NRSUBLOTE = NRSUBLOTE
            FROM POSESTATU
            WHERE CDFILIAL     = @P_CDFILIAL     AND
                  CDALMOXARIFE = @V_CDALMOXARIFE AND
                  CDLOCALESTOQ = @V_CDLOCALESTOQ AND
                  CDPRODUTO    = @P_CDPRODUTO    AND
                  QTTOTALESTOQ > 0
            ORDER BY NRLOTEESTQ, NRSUBLOTE;
         END;
      END; */

      SELECT @V_QTESTOQDIA = SUM((D.QTESTOQDIA/P.VRFATOCONV))
       FROM PRODUTO P, POSESTDIA D, PRODFILI F, PARAMFILIAL PF
       WHERE (P.CDPRODUTO    = @P_CDPRODUTO)    AND
             (D.CDFILIAL     = @P_CDFILIAL)     AND
             (D.CDALMOXARIFE = @V_CDALMOXARIFE) AND
             (D.CDLOCALESTOQ = @V_CDLOCALESTOQ) AND
             (D.CDPRODUTO    = P.CDPRODESTO)    AND
             (P.CDPRODESTO   = F.CDPRODUTO)     AND
             (F.CDFILIAL     = @P_CDFILIAL)     AND
             (F.CDFILIAL     = PF.CDFILIAL)     AND
             (DTPOSIESTQ = (SELECT MAX(DTPOSIESTQ)
                            FROM POSESTDIA
                            WHERE (CDFILIAL     = D.CDFILIAL)     AND
                                  (CDALMOXARIFE = D.CDALMOXARIFE) AND
                                  (CDLOCALESTOQ = D.CDLOCALESTOQ) AND
                                  (NRLOTEESTQ   = D.NRLOTEESTQ)   AND
                                  (NRSUBLOTE    = D.NRSUBLOTE)    AND
                                  (CDPRODUTO    = P.CDPRODESTO)    AND
                                  (DTPOSIESTQ  <= @P_DTREFERENCIA+1)));
   END;

   IF @P_ALMOXARIFE <> 'N' BEGIN
      SELECT @V_QTESTOQDIA = (D.QTESTOQDIA/P.VRFATOCONV)
       FROM PRODUTO P, POSESTDIA D, PRODFILI F, PARAMFILIAL PF
       WHERE (P.CDPRODUTO    = @P_CDPRODUTO)    AND
             (D.CDFILIAL     = @P_CDFILIAL)     AND
             (D.CDALMOXARIFE = @V_CDALMOXARIFE) AND
             (D.CDLOCALESTOQ = @V_CDLOCALESTOQ) AND
             (D.NRLOTEESTQ   = @V_NRLOTEESTQ)   AND
             (D.NRSUBLOTE    = @V_NRSUBLOTE)    AND
             (D.CDPRODUTO    = P.CDPRODESTO)    AND
             (P.CDPRODESTO   = F.CDPRODUTO)     AND
             (F.CDFILIAL     = @P_CDFILIAL)     AND
             (F.CDFILIAL     = PF.CDFILIAL)     AND
             (DTPOSIESTQ = (SELECT MAX(DTPOSIESTQ)
                            FROM POSESTDIA
                            WHERE (CDFILIAL     = @P_CDFILIAL)     AND
                                  (CDALMOXARIFE = @V_CDALMOXARIFE) AND
                                  (CDLOCALESTOQ = @V_CDLOCALESTOQ) AND
                                  (NRLOTEESTQ   = @V_NRLOTEESTQ)   AND
                                  (NRSUBLOTE    = @V_NRSUBLOTE)    AND
                                  (CDPRODUTO    = P.CDPRODESTO)    AND
                                  (DTPOSIESTQ  <= @P_DTREFERENCIA+1)));
   END;

   RETURN(@V_QTESTOQDIA);
END
GO

-- VERSAO --
EXEC ATUVEROBJ 'QTDE_PRODUTO_LCEST','6.05.000';
GO


