import {
    Http, IDictionary, Metadata,
} from '@zeedhi/core';
import {
    ApexChart, Text,
} from '@zeedhi/common';

export class FrameProposalController {
    public async mountCharts({ component }: any, route: string, date: any, text: string) {
        // const dateRange = Metadata.getInstance<DateRange>('range-dashboard').value;
        const dataLabels: any = [];
        const dataSeries: any = [];
        const periodText = Metadata.getInstance<Text>(text);

        if (date !== '') periodText.text = `5 Principais Escopos | Período: ${date[0]} - ${date[1]}`;
        else periodText.text = '5 Principais Escopos | Período: Últimos 30 dias';

        await Http.post(route, {
            DTINICIO: (date === '' || date.length < 1) ? null : date[0],
            DTFINAL: (date === '' || date.length < 2) ? null : date[1],
        }).then((response: IDictionary) => {
            if (response.data.dataset.chart.length) {
                response.data.dataset.chart.forEach((dados: IDictionary) => {
                    dataLabels.push(dados.NMTIPOORCAMENTO);
                    dataSeries.push(dados.QUANTIDADE || dados.VALOR);
                });
            } else {
                dataLabels.push('Nenhum dado disponível');
                dataSeries.push(100);
            }
        });
        const options = { series: dataSeries, labels: dataLabels };
        component.updateChart(options);
    }

    public amountOfProposalAccepted({ component }: any) {
        const pAccepted = Metadata.getInstance<ApexChart>('radial-chart-amountOfProposalAccepted_PROPOSTA');
        const text = Metadata.getInstance<Text>('subtitle-amountOfProposalAccepted').name;
        const route = '/amountOfProposalAccepted';

        const date = (component.component === 'ZdDateRange') ? component.value : '';
        this.mountCharts({ component: pAccepted }, route, date, text);
    }

    public valueOfAcceptedProposal({ component }: any) {
        const pAccepted = Metadata.getInstance<ApexChart>('pie-chart-valueOfAcceptedProposal_PROPOSTA');
        const text = Metadata.getInstance<Text>('subtitle-valueOfAcceptedProposal').name;
        const route = '/valueOfAcceptedProposal';

        const date = (component.component === 'ZdDateRange') ? component.value : '';
        this.mountCharts({ component: pAccepted }, route, date, text);
    }

    public valueOfAcceptedProposalXBusinessPartner({ component }: any) {
        const pAccepted = Metadata.getInstance<ApexChart>('bar-chart-valueOfAcceptedProposalXBusinessPartner_PROPOSTA');
        const text = Metadata.getInstance<Text>('subtitle-valueOfAcceptedProposalXBusinessPartner').name;
        const route = '/valueOfAcceptedProposalXBusinessPartner';

        const date = (component.component === 'ZdDateRange') ? component.value : '';
        this.mountChartBar({ component: pAccepted }, route, date, text);
    }

    public async mountChartBar({ component }: any, route: string, date: any, text: string) {
        const datab: any = [];
        const periodText = Metadata.getInstance<Text>(text);

        if (date !== '') periodText.text = `15 Principais Parceiros de Negócio | Período: ${date[0]} - ${date[1]}`;
        else periodText.text = '15 Principais Parceiros de Negócio | Período: Últimos 30 dias';

        await Http.post(route, {
            DTINICIO: (date === '' || date.length < 1) ? null : date[0],
            DTFINAL: (date === '' || date.length < 2) ? null : date[1],
        }).then((response: IDictionary) => {
            if (response.data.dataset.chart.length) {
                response.data.dataset.chart.forEach((dados: IDictionary) => {
                    datab.push({
                        name: dados.NMTIPOORCAMENTO,
                        data: [dados.VALOR],
                    });
                    component.options.xaxis.categories.push('');
                });
            } else {
                datab.push({
                    name: 'Nenhum dado disponível',
                    data: [100],
                });
            }
            const options = { series: datab };
            component.updateChart(options);
        });
    }
}
